==> haskell-htf-0.15.0.1-72-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HTF
version:              0.15.0.1
visibility:           public
id:                   HTF-0.15.0.1-EClixP7hlcREjUJGdm94kP
key:                  HTF-0.15.0.1-EClixP7hlcREjUJGdm94kP
license:              LGPL-2.1-only
copyright:            (c) 2005-2023 Stefan Wehr
maintainer:           Stefan Wehr
author:               Stefan Wehr
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ directory in
    the HTF repo provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  7c071c2634e9e31e66e725cf99563106
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/HTF-0.15.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HTF-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.1-EClixP7hlcREjUJGdm94kP
depends:
    Diff-0.4.1-GFCkXoW1sOmEQbYHDvlnNI
    HUnit-1.6.2.0-4gkKXmDNQefEQuipMNWISY
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr array-0.5.4.0 base-4.16.4.0
    base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj bytestring-0.11.4.0
    containers-0.6.5.1 cpphs-1.20.9.1-1K2ccivGg76HqdQttHm61m
    directory-1.3.6.2 haskell-src-1.0.4-BbPxJCIpnFXJgeYTb15YMh
    lifted-base-0.2.3.12-LPwBSk7hxRfLQ1PzpNPxYn
    monad-control-1.0.3.1-I8GZevPHGG9CaaoPHICfGK mtl-2.2.2
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg pretty-1.1.3.6
    process-1.6.16.0 random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh
    regex-compat-0.95.2.1-6r4iKSNuQHkEjgz1ilm8wy text-1.2.5.0
    time-1.11.1.1 unix-2.7.2.2 vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    xmlgen-0.6.2.2-E1PRz1AmZIB31yCWeSrBlm

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-htf-0.15.0.1-123.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HTF
version:              0.15.0.1
visibility:           public
id:                   HTF-0.15.0.1-KNB9he5NEz0NTMIPm3lV
key:                  HTF-0.15.0.1-KNB9he5NEz0NTMIPm3lV
license:              LGPL-2.1-only
copyright:            (c) 2005-2023 Stefan Wehr
maintainer:           Stefan Wehr
author:               Stefan Wehr
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ directory in
    the HTF repo provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  baa54aad652f739e5d8a3933a01b78da
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/HTF-0.15.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HTF-0.15.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HTF-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.1-KNB9he5NEz0NTMIPm3lV
depends:
    Diff-0.4.1-Jc1TR9aaNUv129X0zlHNSG
    HUnit-1.6.2.0-DucYFi7W996LJfea0vxExR
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy array-0.5.4.0 base-4.17.2.1
    base64-bytestring-1.2.1.0-51qKIpJ73TV1AKDjoSOLuj
    bytestring-0.11.5.3 containers-0.6.7
    cpphs-1.20.9.1-KMTErBmnvc26XA8bncSIwV directory-1.3.7.1
    haskell-src-1.0.4.1-Bdtme0ZkhXeIZTcYRvVlhO
    lifted-base-0.2.3.12-4lqeQZi6Is2ElxL17hUAIJ
    monad-control-1.0.3.1-CU0oSebqH0K53geyhZCKTM mtl-2.2.2
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 pretty-1.1.3.6
    process-1.6.18.0 random-1.2.1.2-5Y3bNr2vhgE1UbXPPVLWyj
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8 text-2.0.2 time-1.12.2
    unix-2.7.3 vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16
    xmlgen-0.6.2.2-3FNDMihSCGTGYIsl3yXFQb

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
